@@ -1,11 +1,12 @@
-# $Id: kill.R,v 1.3 2003/07/17 19:27:26 warnes Exp $
+# $Id: kill.R,v 1.4 2004/05/25 19:12:32 warnes Exp $
 
 kill <- function(pid, signal=15)
   {
     .C("Rfork_kill",
        as.integer(pid),
        as.integer(signal),
-       flag=integer(1)
+       flag=integer(1),
+       PACKAGE="fork"
        )$flag
   }
 
